#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import absolute_import, division, print_function, unicode_literals

__license__   = 'GPL v3'
__copyright__ = u'2019, Jürgen Habelt <juergen@habelt-jena.de>'
__docformat__ = 'restructuredtext en'

import os, re


class Extractor(object):
    '''
    The base class of all derived extractor classes
    '''
    
    @property
    def settings(self):
        '''
        Settings with attribute semantic
        '''
        return self.invoker.settings
    
    
    @property
    def strip(self):
        '''
        Strip regex  with attribute semantic
        '''
        if not self.settings['use_strip']:
            return r'^'
        else:
            return self.settings['strip']
    
    
    def strip_from_title(self, title):
        '''
        Use the strip option to strip from the beginning
        @param title: the title from which to strip
        '''
        if title == None:
            return ''
                
        title = title.strip()
        title = re.sub(r'(?m)\s+', ' ', title)

        strip = self.strip                                                      # stems from derived class
        regex = strip + r'(.*?)$'                                               # concatenate 2 regexes
        return re.search(regex, title).group(1)                                 # strip from the beginning    
        
    
    def change_extension(self, path, ext):
        '''
        Can be used to change the extension of a file path
        @param path: the path to be changed
        @param ext: the new extension
        '''
        pre = os.path.splitext(path)[0]
        return pre + ext